close all

tmax = 100;
sigma = 10;
b = 8/3;
r = .5;   % origin stable
%r = 1.25;  % origin weakly unstable
%r = 15;   % see cycle better
%r = 23.5; % cycle weakly stable
%r = 28;   % cycle unstable: chaos

if r > 1
  Cp = sqrt(b*(r-1));
  fprintf(1,'Fixed points C+ = (%g,%g,%g)\n',Cp,Cp,r-1)
end

% Value of r for subcritical Hopf bifurcation.
rH = sigma*(sigma+b+3)/(sigma-b-1)

% Initial condition.
x0 = .2;
y0 = .2;
z0 = .2;

opts = odeset('RelTol',1e-10,'AbsTol',1e-8);

t = linspace(0,tmax,30000);
[~,X] = ode45(@lorenz,t,[x0 y0 z0],opts,sigma,b,r);

x = X(:,1);
y = X(:,2);
z = X(:,3);

figure(1)
comet3(x,y,z)
xlabel('x')
ylabel('y')
zlabel('z')

figure(2)
plot3(x,y,z)
hold on
% Mark initial condition with a red circle.
plot3(x0,y0,z0,'ro','MarkerSize',10)
% Mark final state with a magenta dot.
plot3(x(end),y(end),z(end),'m.','MarkerSize',20)

% Mark fixed point at origin with a green star.
plot3(0,0,0,'gp','MarkerSize',10)
if r > 1
  % Mark fixed points C+/- red star.
  plot3(Cp,Cp,r-1,'rp','MarkerSize',10)
  plot3(-Cp,-Cp,r-1,'rp','MarkerSize',10)
end

hold off
xlabel('x')
ylabel('y')
zlabel('z')

figure(3)
subplot(3,1,1)
plot(t,x)
ylabel('x')
subplot(3,1,2)
plot(t,y)
ylabel('y')
subplot(3,1,3)
plot(t,z)
xlabel('t')
ylabel('z')

% Now simulate a second trajectory near the first.
rng('default')
X1 = [x0 y0 z0] + 1e-8*rand(1,3);
[~,X1] = ode45(@lorenz,t,X1,opts,sigma,b,r);

figure(4)
dX = X(:,1) - X1(:,1);
semilogy(t,sqrt(sum(dX.^2,2)),'k-','LineWidth',1.5)
xlabel('t')
ylabel('|\Delta X|')
